@@ -1,6 +1,7 @@
 import logging
 
 from django.apps.config import AppConfig
+from django.conf import settings
 from django.db.backends.base import base as django_db_base
 from django.dispatch import Signal
 
@@ -34,6 +35,8 @@ for module_name, error_name in database_modules:
 
 def monkeypatch_django() -> None:
     def ensure_connection_with_retries(self: django_db_base.BaseDatabaseWrapper) -> None:
+        self._max_dbconn_retry_times = getattr(settings, "MAX_DBCONN_RETRY_TIMES", 1)
+
         if self.connection is not None and hasattr(self.connection, 'closed') and self.connection.closed:
             _log.debug("failed connection detected")
             self.connection = None
@@ -45,7 +48,10 @@ def monkeypatch_django() -> None:
                     self.connect()
                 except Exception as e:
                     if isinstance(e, _operror_types):
-                        if hasattr(self, "_connection_retries") and self._connection_retries >= 1:
+                        if (
+                                hasattr(self, "_connection_retries") and
+                                self._connection_retries >= self._max_dbconn_retry_times
+                        ):
                             _log.error("Reconnecting to the database didn't help %s", str(e))
                             del self._in_connecting
                             post_reconnect.send(self.__class__, dbwrapper=self)
@@ -53,7 +59,11 @@ def monkeypatch_django() -> None:
                         else:
                             _log.info("Database connection failed. Refreshing...")
                             # mark the retry
-                            self._connection_retries = 1
+                            try:
+                                self._connection_retries += 1
+                            except AttributeError:
+                                self._connection_retries = 1
+
                             # ensure that we retry the connection. Sometimes .closed isn't set correctly.
                             self.connection = None
                             del self._in_connecting
